tsseg.algorithms.tire package
=============================

Autoencoder-based CPD learning partially time-invariant representations. Supports
time domain, frequency domain or both.

| **Type:** change point detection
| **Supervision:** semi-supervised or unsupervised
| **Requires:** PyTorch

**Implementation:** PyTorch reimplementation of original TF/Keras code by De Ryck,
De Vos & Bertrand (KU Leuven / ETH Zurich). No original licence; authors granted
use.

**Reference:** De Ryck, De Vos & Bertrand (2021), IEEE TSP.

Submodules
----------

tsseg.algorithms.tire.detector module
-------------------------------------

.. automodule:: tsseg.algorithms.tire.detector
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.tire.utils module
----------------------------------

.. automodule:: tsseg.algorithms.tire.utils
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.tire
   :members:
   :show-inheritance:
   :undoc-members:
